package crc
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Module Crc.Crc32Source
This is the algorithm used by HDLC, ANSI X3.66, ITU-T V.42, Ethernet, Serial ATA, MPEG-2, PKZIP, Gzip, Bzip2, PNG and others: http://en.wikipedia.org/wiki/Cyclic_redundancy_check#Commonly_used_and_standardized_CRCs
cstruct ?crc buf computes the CRC of buf with optional initial value crc
string ?crc buf ofs len computes the CRC of the substring of length len starting at offset ofs in string buf with optional initial value crc